@@ -2,7 +2,7 @@
 /**
  *  @brief EfficientGlobalOptimization or EGO algorithm
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@
 #include "openturns/DistFunc.hxx"
 #include "openturns/KrigingAlgorithm.hxx"
 #include "openturns/MultiStart.hxx"
-#include "openturns/ComposedDistribution.hxx"
+#include "openturns/JointDistribution.hxx"
 #include "openturns/Uniform.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -205,7 +205,7 @@ void EfficientGlobalOptimization::run()
   // use the provided kriging result at first iteration
   KrigingResult metaModelResult(krigingResult_);
 
-  while ((!exitLoop) && (evaluationNumber < getMaximumEvaluationNumber()))
+  while ((!exitLoop) && (evaluationNumber < getMaximumCallsNumber()))
   {
     Scalar optimalValueSubstitute = optimalValue[0];
     if (hasNoise)
@@ -239,14 +239,14 @@ void EfficientGlobalOptimization::run()
       const Point upperBound(bounds.getUpperBound());
       const Interval::BoolCollection finiteLowerBound(bounds.getFiniteLowerBound());
       const Interval::BoolCollection finiteUpperBound(bounds.getFiniteUpperBound());
-      ComposedDistribution::DistributionCollection coll;
+      JointDistribution::DistributionCollection coll;
       for (UnsignedInteger i = 0; i < dimension; ++ i)
       {
         if (!finiteLowerBound[i] || !finiteUpperBound[i])
           throw InvalidArgumentException(HERE) << "Bounds must be finite";
         coll.add(Uniform(lowerBound[i], upperBound[i]));
       }
-      const ComposedDistribution distribution(coll);
+      const JointDistribution distribution(coll);
       Sample improvementExperiment(distribution.getSample(multiStartExperimentSize_));
       // retain best P/N points as starting points
       improvementExperiment.stack(improvementObjective(improvementExperiment));
@@ -320,7 +320,12 @@ void EfficientGlobalOptimization::run()
     }
 
     // improvement stopping criterion
-    const Bool improvementStop = (improvementValue[0] < improvementFactor_ * std::abs(optimalValue[0]));
+    Bool improvementStop = false;
+    const Scalar improvementTerm = improvementFactor_ * std::abs(optimalValue[0]);
+    if (problem.isMinimization())
+      improvementStop = improvementValue[0] < improvementTerm;
+    else
+      improvementStop = improvementValue[0] > improvementTerm;
     if (improvementStop) LOGINFO(OSS() << "Stopped algorithm over the improvement criterion");
     exitLoop = exitLoop || improvementStop;
 
@@ -341,7 +346,7 @@ void EfficientGlobalOptimization::run()
     // callbacks
     if (progressCallback_.first)
     {
-      progressCallback_.first((100.0 * evaluationNumber) / getMaximumEvaluationNumber(), progressCallback_.second);
+      progressCallback_.first((100.0 * evaluationNumber) / getMaximumCallsNumber(), progressCallback_.second);
     }
     if (stopCallback_.first)
     {
