@@ -4,7 +4,7 @@
  *  using a maximization of the likelihood function. We use here some articles of J.A.Mauricio (http://www.ucm.es/info/ecocuan/jam/)
  *  to use an efficient method
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -296,7 +296,7 @@ Point ARMALikelihoodFactory::computeLogLikelihoodInequalityConstraint(const Poin
     }
 
     // Computation of EigenValues without keeping intact (matrix not used after)
-    const Collection<Complex> eigenValues(matrix.computeEigenValues(false));
+    const Collection<Complex> eigenValues(matrix.computeEigenValuesInPlace());
 
     // Find the largest eigenvalue module
     Scalar s = std::norm(eigenValues[0]);
@@ -330,7 +330,7 @@ Point ARMALikelihoodFactory::computeLogLikelihoodInequalityConstraint(const Poin
     }
 
     // Computation of EigenValues without keeping intact (matrix not used after)
-    const Collection<Complex> eigenValues(matrix.computeEigenValues(false));
+    const Collection<Complex> eigenValues(matrix.computeEigenValuesInPlace());
 
     // Find the largest eigenvalue module
     Scalar s = std::norm(eigenValues[0]);
@@ -351,7 +351,7 @@ Point ARMALikelihoodFactory::computeLogLikelihoodInequalityConstraint(const Poin
     }
   }
   // Computation of EigenValues without keeping intact (matrix not used after)
-  const Point eigenValues(covarianceMatrix.computeEigenValues(false));
+  const Point eigenValues(covarianceMatrix.computeEigenValuesInPlace());
 
   // Find the largest eigenvalue module
   Scalar s = eigenValues[0];
@@ -381,10 +381,10 @@ void ARMALikelihoodFactory::initializeCobylaSolverParameter()
   if (cobyla == NULL) throw InternalException(HERE);
 
   cobyla->setRhoBeg(ResourceMap::GetAsScalar("ARMALikelihoodFactory-DefaultRhoBeg"));
-  cobyla->setIgnoreFailure(true);
+  cobyla->setCheckStatus(false);
 
   solver_.setMaximumAbsoluteError(ResourceMap::GetAsScalar("ARMALikelihoodFactory-DefaultRhoEnd"));
-  solver_.setMaximumEvaluationNumber(ResourceMap::GetAsUnsignedInteger("ARMALikelihoodFactory-DefaultMaximumEvaluationNumber"));
+  solver_.setMaximumCallsNumber(ResourceMap::GetAsUnsignedInteger("ARMALikelihoodFactory-DefaultMaximumCallsNumber"));
 }
 
 /* Optimization solver accessor */
@@ -487,18 +487,6 @@ String ARMALikelihoodFactory::__str__(const String & ) const
   return this->__repr__();
 }
 
-/* Verbosity accessor */
-Bool ARMALikelihoodFactory::getVerbose() const
-{
-  LOGWARN("ARMALikelihoodFactory::getVerbose is deprecated");
-  return Log::HasDebug();
-}
-
-void ARMALikelihoodFactory::setVerbose(const Bool /*verbose*/)
-{
-  LOGWARN("ARMALikelihoodFactory::setVerbose is deprecated");
-}
-
 /* Build method */
 ARMA ARMALikelihoodFactory::build(const TimeSeries & timeSeries) const
 {
